# Ingress

[![Build Status](https://travis-ci.org/tebeka/ingress.svg?branch=master)](https://travis-ci.org/tebeka/ingress)

Ingress is a Python REPL over the network to your application (very much like
Twisted manhole).

Once installed, you can 'telnet <host> <port>' and run Python commands on your
server environment. This is very helpful in debugging servers.

This one uses only modules found in the standard library.
